use strict;
use warnings;
use xt::kwalitee::Test;

xt::kwalitee::Test::run(
  ['J/JJ/JJUDD/DBIx-Class-TimeStamp-HiRes-v1.0.0.tar.gz', 0], # 2596
  ['N/NI/NIELSD/Speech-Google-0.5.tar.gz', 0], # 2907
  ['S/SC/SCILLEY/POE/Component/IRC/Plugin/IRCDHelp-0.02.tar.gz', 0], # 3243
  ['A/AN/ANANSI/Anansi-Library-0.02.tar.gz', 0], # 3365
  ['J/JE/JEEN/WebService-Aladdin-0.08.tar.gz', 0], # 4287
  ['S/SM/SMUELLER/Math-SymbolicX-Complex-1.01.tar.gz', 0], # 4719
  ['I/IA/IAMCAL/Flickr-API-1.06.tar.gz', 0], # 5172
  ['A/AN/ANANSI/Anansi-ObjectManager-0.06.tar.gz', 0], # 5246
);
