use strict;
use warnings;
use xt::kwalitee::Test;

xt::kwalitee::Test::run(
  ['G/GU/GUGOD/Kwiki-Session-0.01.tar.gz', 0], # 7880
  ['G/GU/GUGOD/Kwiki-Widgets-Links-0.01.tar.gz', 0], # 8214
  ['C/CL/CLSUNG/Lingua-ZH-Segment-0.02.tar.gz', 0], # 8236
  ['R/RH/RHUNDT/Catalyst-Model-Oryx-0.01.tar.gz', 0], # 8255
  ['X/XE/XERN/Template-Plugin-IO-All-0.01.tar.gz', 0], # 8462
  ['I/IJ/IJLIAO/WWW-Scraper-ISBN-TWSrbook_Driver-0.01.tar.gz', 0], # 9139
  ['I/IJ/IJLIAO/WWW-Scraper-ISBN-TWYlib_Driver-0.01.tar.gz', 0], # 9199
  ['I/IJ/IJLIAO/WWW-Scraper-ISBN-TWTenlong_Driver-0.01.tar.gz', 0], # 9210
  ['I/IJ/IJLIAO/WWW-Scraper-ISBN-TWPchome_Driver-0.01.tar.gz', 0], # 9308
  ['I/IJ/IJLIAO/WWW-Scraper-ISBN-TWSoidea_Driver-0.01.tar.gz', 0], # 9348

  # M::I 1.04
  ['K/KA/KARMAN/Dezi-UI-0.001000.tar.gz', 0],
);
