use strict;
use warnings;
use xt::kwalitee::Test;

xt::kwalitee::Test::run(
  ['S/SE/SEVEAS/Term-Multiplexed-0.1.0.tar.gz', 0], # 1701
  ['U/UN/UNBIT/Net-uwsgi-1.1.tar.gz', 0], # 2409
  ['N/NI/NIELSD/Speech-Google-0.5.tar.gz', 0], # 2907
  ['M/MU/MUIR/modules/rinetd.pl-1.2.tar.gz', 0], # 4319
  ['S/SR/SRPATT/Finance-Bank-CooperativeUKPersonal-0.02.tar.gz', 0], # 4991
  ['I/IA/IAMCAL/Flickr-API-1.06.tar.gz', 0], # 5172
  ['P/PJ/PJB/Speech-Speakup-1.04.tar.gz', 0], # 7410
  ['F/FI/FIBO/Task-Viral-20130508.tar.gz', 0], # 8128
  ['A/AD/ADAMBA/Algorithm-MOS-0.001.tar.gz', 0], # 8570
  ['F/FI/FIBO/Task-BeLike-FIBO-20130508.tar.gz', 0], # 8922
);
