use strict;
use warnings;
use xt::kwalitee::Test;

xt::kwalitee::Test::run(
  ['U/UN/UNBIT/Net-uwsgi-1.1.tar.gz', 0], # 2409
  ['N/NI/NIELSD/Speech-Google-0.5.tar.gz', 0], # 2907
  ['B/BE/BENNING/Math-BaseMulti-1.00.tar.gz', 0], # 2942
  ['H/HE/HEYTRAV/Mojolicious-Plugin-Libravatar-1.08.tar.gz', 0], # 3415
  ['T/TX/TXH/Template-Plugin-Filter-MinifyHTML-0.02.tar.gz', 0], # 3484
  ['M/MA/MANIGREW/SEG7-1.0.1.tar.gz', 0], # 3847
  ['M/MU/MUIR/modules/rinetd.pl-1.2.tar.gz', 0], # 4319
  ['G/GS/GSB/WWW-Crab-Client-0.03.tar.gz', 0], # 4352
  ['R/RS/RSHADOW/libmojolicious-plugin-human-perl_0.6.orig.tar.gz', 0], # 4504
  ['S/SR/SRPATT/Finance-Bank-CooperativeUKPersonal-0.02.tar.gz', 0], # 4991
);
