use strict;
use warnings;
use xt::kwalitee::Test;

xt::kwalitee::Test::run(
  ['U/UN/UNBIT/Net-uwsgi-1.1.tar.gz', 0], # 2409
  ['N/NI/NIELSD/Speech-Google-0.5.tar.gz', 0], # 2907
  ['A/AN/ANANSI/Anansi-Actor-0.04.tar.gz', 0], # 3157
  ['S/SC/SCILLEY/POE/Component/IRC/Plugin/IRCDHelp-0.02.tar.gz', 0], # 3243
  ['A/AN/ANANSI/Anansi-Library-0.02.tar.gz', 0], # 3365
  ['H/HI/HITHIM/Socket-Mmsg-0.02.tar.gz', 0], # 3946
  ['C/CI/CINDY/AnyEvent-HTTPD-CookiePatch-v0.1.0.tar.gz', 0], # 4162
  ['B/BE/BENNIE/ACME-KeyboardMarathon-1.15.tar.gz', 0], # 4479
  ['M/ML/MLX/Algorithm-Damm-1.001.002.tar.gz', 0], # 4537
);
